@@ -31,7 +31,7 @@ Speed::Speed()
 
 bool Speed::SetModel(Lum::Base::Model* model)
 {
-  this->model=dynamic_cast<Lum::Model::Double*>(model);
+  this->model=dynamic_cast<Lum::Model::Number*>(model);
 
   Lum::Control::SetModel(this->model);
 
@@ -72,18 +72,18 @@ void Speed::Draw(Lum::OS::DrawInfo* draw,
         unit=GetSpeedNoDataUnit();
     }
     else  {
-      value=GetSpeedAsString(model->Get());
-      unit=GetSpeedUnitAsString(model->Get());
+      value=GetSpeedAsString(model->GetDouble());
+      unit=GetSpeedUnitAsString(model->GetDouble());
     }
-  }  
+  }
   else {
     if (!model.Valid() || model->IsNull()) {
      value=L"-,--";
      unit=GetSpeedNoDataUnit();
     }
     else {
-      value=GetSpeedAsString(model->Get());
-      unit=GetSpeedUnitAsString(model->Get());
+      value=GetSpeedAsString(model->GetDouble());
+      unit=GetSpeedUnitAsString(model->GetDouble());
     }
   }
 
